@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.42.2.5 2003/03/31 08:52:41 joern Exp $
+# $Id: Config.pm,v 1.42.2.6 2003/05/01 12:02:21 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -75,7 +75,7 @@ my %CONFIG_PARAMETER = (
 		type  => 'string',
 		value => 'mplayer <dvd://%t -aid %(%a+128) -chapter %c -dvdangle %m>',
 		presets => [
-			'mplayer <dvd://%t -aid %(%a+128) -chapter %c -dvdangle %m>',
+			'mplayer <dvd://%t -aid %(%a+128) -chapter %c-%c -dvdangle %m>',
 			'xine -a %a -p <dvd://%t.%c>',
 		],
 	},
@@ -533,7 +533,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.42.2.5 2003/03/31 08:52:41 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.42.2.6 2003/05/01 12:02:21 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
